package com.ruoyi.zhiyuanzhe.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.zhiyuanzhe.domain.BActivity;
import com.ruoyi.zhiyuanzhe.domain.request.ActivityInviteRequest;
import com.ruoyi.zhiyuanzhe.domain.request.EventRecommendationsRequest;
import com.ruoyi.zhiyuanzhe.domain.response.ActivityResponse;
import com.ruoyi.zhiyuanzhe.service.IBActivityService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * 活动管理Controller
 *
 * @author ruoyi
 * @date 2023-09-18
 */
@RestController
@Api(tags = "活动管理")
@RequestMapping("/zhiyuanzhe/activity")
@Transactional(rollbackFor = Exception.class)
public class BActivityController extends BaseController {

    @Resource
    private IBActivityService bActivityService;

    /**
     * 查询活动管理列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询活动管理列表", response = BActivity.class)
    public TableDataInfo list(BActivity bActivity) {
        startPage();
        List<BActivity> list = bActivityService.selectBActivityList(bActivity);
        return getDataTable(list);
    }


    /**
     * 获取活动管理详细信息
     */
    @ApiOperation(value = "获取活动管理详细信息", response = ActivityResponse.class)
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bActivityService.selectBActivityById(id));
    }

    /**
     * 新增活动管理
     */
    @ApiOperation(value = "新增活动管理")
    @PostMapping
    public AjaxResult add(@RequestBody BActivity bActivity) {
        bActivityService.insertBActivity(bActivity);
        return success();
    }

    /**
     * 修改活动管理
     */
    @ApiOperation(value = "修改活动管理")
    @PutMapping
    public AjaxResult edit(@RequestBody BActivity bActivity) {
        bActivityService.updateBActivity(bActivity);
        return success();
    }

    /**
     * 邀请人员
     *
     * @param req 活动id和用户id
     * @return 响应类
     */
    @ApiOperation(value = "邀请人员")
    @PostMapping("invite")
    public AjaxResult invite(@RequestBody ActivityInviteRequest req) {
        bActivityService.invite(req);
        return success();
    }

    /**
     * 邀请人员新
     *
     * @param id id
     * @return 响应类
     */
    @ApiOperation(value = "邀请人员新")
    @PostMapping("inviteTwo/{id}")
    public AjaxResult inviteTwo(@PathVariable("id") Long id) {
        bActivityService.inviteTwo(id);
        return success();
    }

    /**
     * 删除活动管理
     */
    @ApiOperation(value = "删除活动管理")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bActivityService.deleteBActivityByIds(ids));
    }

    /**
     * 活动推荐
     *
     * @param req 活动搜索条件
     * @return 活动信息
     */
    @GetMapping("/eventRecommendations")
    @ApiOperation(value = "活动推荐", response = BActivity.class)
    public TableDataInfo eventRecommendations(EventRecommendationsRequest req) {
        startPage();
        List<BActivity> list = bActivityService.eventRecommendations(req);
        return getDataTable(list);
    }

    /**
     * 活动邀请列表
     *
     * @param req 活动搜索条件
     * @return 活动信息
     */
    @GetMapping("/eventInvitations")
    @ApiOperation(value = "活动邀请列表", response = BActivity.class)
    public TableDataInfo eventInvitations(EventRecommendationsRequest req) {
        startPage();
        List<BActivity> list = bActivityService.eventInvitations(req);
        return getDataTable(list);
    }

    /**
     * 报名
     *
     * @param req 活动id和用户id
     * @return 响应类
     */
    @ApiOperation(value = "报名")
    @PostMapping("enroll")
    public AjaxResult enroll(@RequestBody ActivityInviteRequest req) {
        bActivityService.enroll(req);
        return success();
    }
}
