package com.ruoyi.zhiyuanzhe.service.impl;

import com.ruoyi.zhiyuanzhe.domain.BActivity;
import com.ruoyi.zhiyuanzhe.domain.BActivityUser;
import com.ruoyi.zhiyuanzhe.domain.BPersonTags;
import com.ruoyi.zhiyuanzhe.domain.request.ActivityInviteRequest;
import com.ruoyi.zhiyuanzhe.domain.request.EventRecommendationsRequest;
import com.ruoyi.zhiyuanzhe.mapper.ActivityUserMapper;
import com.ruoyi.zhiyuanzhe.service.ActivityUserService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 活动人员关联业务实现层
 *
 * @author wu
 * @since 2023/9/28 15:38
 */
@Service
public class ActivityUserServiceImpl implements ActivityUserService {

    @Resource
    private ActivityUserMapper activityUserMapper;

    /**
     * 批量新增数据
     *
     * @param list 人员活动关联数据
     */
    @Override
    public void addList(List<BActivityUser> list) {
        for (BActivityUser user : list) {
            activityUserMapper.add(user);
        }
    }

    /**
     * 删除所有用户
     *
     * @param activityId – 活动标签
     */
    @Override
    public void delByActivityId(Long activityId) {
        activityUserMapper.delByActivityId(activityId);
    }

    /**
     * 查询人员信息
     *
     * @param status     状态
     * @param activityId 活动id
     * @return 人员信息
     */
    @Override
    public List<BPersonTags> findUserByStatusAndActivityId(Integer status, Long activityId) {
        return activityUserMapper.findUserByStatusAndActivityId(status, activityId);
    }

    /**
     * 邀请人员
     *
     * @param req 活动id和用户id
     */
    @Override
    public void invite(ActivityInviteRequest req) {
        activityUserMapper.invite(req);
    }

    /**
     * 活动推荐
     *
     * @param req 活动搜索条件
     * @return 活动信息
     */
    @Override
    public List<BActivity> eventRecommendations(EventRecommendationsRequest req) {
        return activityUserMapper.eventRecommendations(req);
    }

    @Override
    public void enroll(ActivityInviteRequest req) {
        activityUserMapper.enroll(req);
    }

    /**
     * 活动邀请列表
     *
     * @param req 活动搜索条件
     * @return 活动信息
     */
    @Override
    public List<BActivity> eventInvitations(EventRecommendationsRequest req) {
        return activityUserMapper.eventInvitations(req);
    }

    /**
     * 邀请人员新
     *
     * @param id id
     */
    @Override
    public void inviteTwo(Long id) {
        activityUserMapper.inviteTwo(id);
    }
}
