package com.ruoyi.zhiyuanzhe.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.zhiyuanzhe.domain.BDistributionRecords;
import com.ruoyi.zhiyuanzhe.domain.request.BActivityPointsRequest;
import com.ruoyi.zhiyuanzhe.domain.request.SubmitRequest;
import com.ruoyi.zhiyuanzhe.mapper.BDistributionRecordsMapper;
import com.ruoyi.zhiyuanzhe.service.IBDistributionRecordsService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;


/**
 * 发放记录Service业务层处理
 *
 * @author ruoyi
 * @date 2023-09-19
 */
@Service
public class BDistributionRecordsServiceImpl implements IBDistributionRecordsService {

    @Resource
    private BDistributionRecordsMapper bDistributionRecordsMapper;

    /**
     * 查询发放记录
     *
     * @param id 发放记录主键
     * @return 发放记录
     */
    @Override
    public BDistributionRecords selectBDistributionRecordsById(Long id) {
        BDistributionRecords records = bDistributionRecordsMapper.selectBDistributionRecordsById(id);
        if (BeanUtil.isEmpty(records)) {
            throw new ServiceException("所选数据不存在");
        }
        return records;
    }

    /**
     * 查询发放记录列表
     *
     * @param bDistributionRecords 发放记录
     * @return 发放记录
     */
    @Override
    public List<BDistributionRecords> selectBDistributionRecordsList(BDistributionRecords bDistributionRecords) {
        return bDistributionRecordsMapper.selectBDistributionRecordsList(bDistributionRecords);
    }

    /**
     * 新增发放记录
     *
     * @param bDistributionRecords 发放记录
     * @return 结果
     */
    @Override
    public int insertBDistributionRecords(BDistributionRecords bDistributionRecords) {
        bDistributionRecords.setCreateTime(DateUtils.getNowDate());
        return bDistributionRecordsMapper.insertBDistributionRecords(bDistributionRecords);
    }

    /**
     * 修改发放记录
     *
     * @param bDistributionRecords 发放记录
     * @return 结果
     */
    @Override
    public int updateBDistributionRecords(BDistributionRecords bDistributionRecords) {
        bDistributionRecords.setUpdateTime(DateUtils.getNowDate());
        return bDistributionRecordsMapper.updateBDistributionRecords(bDistributionRecords);
    }

    /**
     * 批量删除发放记录
     *
     * @param ids 需要删除的发放记录主键
     * @return 结果
     */
    @Override
    public int deleteBDistributionRecordsByIds(Long[] ids) {
        return bDistributionRecordsMapper.deleteBDistributionRecordsByIds(ids);
    }

    /**
     * 删除发放记录信息
     *
     * @param id 发放记录主键
     * @return 结果
     */
    @Override
    public int deleteBDistributionRecordsById(Long id) {
        return bDistributionRecordsMapper.deleteBDistributionRecordsById(id);
    }

    @Override
    public int submit(SubmitRequest req) {
        return bDistributionRecordsMapper.submit(req);
    }

    /**
     * 查询证书是否被用户兑换
     *
     * @param id     证书id
     * @param userId 用户id
     * @return 兑换记录
     */
    @Override
    public BDistributionRecords findIdAndUserId(Long id, Long userId) {
        return bDistributionRecordsMapper.findIdAndUserId(id, userId);
    }

    /**
     * 获取用户已经使用的积分
     *
     * @param userId 用户id
     * @return 已使用的积分
     */
    @Override
    public Integer findPointsByUserId(Long userId) {
        return bDistributionRecordsMapper.findPointsByUserId(userId);
    }

    /**
     * 发放个性化证书
     *
     * @param req 个性化证书信息
     */
    @Override
    public void issue(BActivityPointsRequest req) {
        BDistributionRecords records = this.selectBDistributionRecordsById(req.getId());
        if (BeanUtil.isEmpty(records)) {
            throw new ServiceException("所选数据不存在");
        }
        // 创建证书发放记录
        records.setType(req.getType());
        records.setStatus(1);
        records.setCourierCompanies(req.getCourierCompanies());
        records.setTrackingNumber(req.getTrackingNumber());
        // 保存发放记录
        this.updateBDistributionRecords(records);
    }
}
