package com.ruoyi.zhiyuanzhe.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.zhiyuanzhe.domain.BCertificates;
import com.ruoyi.zhiyuanzhe.domain.BDistributionRecords;
import com.ruoyi.zhiyuanzhe.domain.request.BCertificatesRequest;
import com.ruoyi.zhiyuanzhe.domain.request.PointsRedemptionExchangeRequest;
import com.ruoyi.zhiyuanzhe.service.IBActivityPointsService;
import com.ruoyi.zhiyuanzhe.service.IBCertificatesService;
import com.ruoyi.zhiyuanzhe.service.IBDistributionRecordsService;
import com.ruoyi.zhiyuanzhe.service.PointsRedemptionService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 积分兑换消费业务实现层
 *
 * @author wu
 * @since 2023/9/27 10:49
 */
@Service
public class PointsRedemptionServiceImpl implements PointsRedemptionService {


    @Resource
    private IBCertificatesService bCertificatesService;

    @Resource
    private IBDistributionRecordsService bDistributionRecordsService;

    @Resource
    private IBActivityPointsService activityPointsService;

    @Resource
    private ISysUserService sysUserService;

    /**
     * 查询可以兑换证书列表
     *
     * @param bCertificates 查询条件
     * @return 个性化证书列表
     */
    @Override
    public List<BCertificates> page(BCertificatesRequest bCertificates) {
        bCertificates.setUserId(SecurityUtils.getUserId());
        return bCertificatesService.PagePointsRedemption(bCertificates);
    }

    /**
     * 兑换证书
     *
     * @param req 兑换证书请求类
     */
    @Override
    public void exchange(PointsRedemptionExchangeRequest req) {
        // 判断证书是否存在
        BCertificates bCertificates = bCertificatesService.selectBCertificatesById(req.getCertificateId());
        if (BeanUtil.isEmpty(bCertificates)) {
            throw new ServiceException("所选证书不存在");
        }
        // 获取用户id
        Long userId = SecurityUtils.getUserId();
        SysUser sysUser = sysUserService.selectUserById(userId);
        if (StrUtil.isEmpty(sysUser.getAddress())) {
            throw new ServiceException("请先填写所在地址");
        }
        // 判断证书是否能兑换
        BDistributionRecords records = bDistributionRecordsService.findIdAndUserId(bCertificates.getId(), userId);
        if (BeanUtil.isNotEmpty(records)) {
            throw new ServiceException("所选证书已经兑换过");
        }
        // 获取用户所有积分
        Integer points = activityPointsService.findPointsByUserId(userId);
        // 获取用户已经使用的积分
        Integer pointsUsed = bDistributionRecordsService.findPointsByUserId(userId);
        points = points != null ? points : 0;
        pointsUsed = pointsUsed != null ? pointsUsed : 0;
        // 计算用户剩余积分
        Integer remainder = points - pointsUsed;
        // 判断积分是否足够
        if ((remainder - bCertificates.getIntegral()) >= 0) {
            // 生成兑换记录
            BDistributionRecords entity = new BDistributionRecords();
            entity.setCertificateId(bCertificates.getId());
            entity.setCreType(2);
            entity.setType(req.getType());
            entity.setUId(userId);
            entity.setStatus(2);
            entity.setAddress(sysUser.getAddress());
            entity.setPhonenumber(sysUser.getConsigneePhonenumber());
            entity.setConsigneeName(sysUser.getConsigneeName());
            bDistributionRecordsService.insertBDistributionRecords(entity);
        } else {
            throw new ServiceException("积分不足");
        }
    }

    /**
     * 查看证书详情
     *
     * @param id 证书id
     * @return 证书详情
     */
    @Override
    public BCertificates findCertificatesById(Long id) {
        return bCertificatesService.selectBCertificatesById(id);
    }

    /**
     * 查询用户所有积分
     *
     * @return 积分
     */
    @Override
    public Integer findIntegral() {
        // 获取用户id
        Long userId = SecurityUtils.getUserId();
        // 获取用户所有积分
        Integer points = activityPointsService.findPointsByUserId(userId);
        // 获取用户已经使用的积分
        Integer pointsUsed = bDistributionRecordsService.findPointsByUserId(userId);
        points = points != null ? points : 0;
        pointsUsed = pointsUsed != null ? pointsUsed : 0;
        // 计算用户剩余积分
        return points - pointsUsed;
    }
}
